@@ -15,6 +15,15 @@ impl RustGenerator {
     }
 
     pub fn generate(&self, iface: Interface) -> rust::Tokens {
+        let wasm_bindgen: rust::Tokens = if cfg!(feature = "wasm-bindgen") {
+            quote! {
+                // Workaround for combined use with `wasm-bindgen`, so we don't have to
+                // patch the `importObject` while loading the WASM module.
+                #[cfg_attr(target_family = "wasm", wasm_bindgen::prelude::wasm_bindgen(js_namespace = window, js_name = __notifier_callback))]
+            }
+        } else {
+            quote!()
+        };
         quote! {
         #[allow(unused)]
         mod api {
@@ -119,6 +128,7 @@ impl RustGenerator {
             fn ffi_waker(_post_cobject: isize, port: i64) -> Waker {
                 waker_fn(move || unsafe {
                     if cfg!(target_family = "wasm") {
+                        #(wasm_bindgen)
                         extern "C" {
                             fn __notifier_callback(idx: i32);
                         }
@@ -306,6 +316,12 @@ impl RustGenerator {
             Instr::LiftNum(in_, out) | Instr::LiftIsize(in_, out) | Instr::LiftUsize(in_, out) => {
                 quote!(let #(self.var(out)) = #(self.var(in_)) as _;)
             }
+            Instr::LiftNumAsU32Tuple(in_low, in_high, out, num_type) => {
+                let ty = self.num_type(*num_type);
+                quote! {
+                   let #(self.var(out)) = #(ty.clone())::from(#(self.var(in_low))) | (#ty::from(#(self.var(in_high))) << 32);
+                }
+            }
             Instr::LowerNumAsU32Tuple(r#in, low, high, _num_type) => {
                 quote! {
                     #(self.var(low)) = #(self.var(r#in)) as u32;
